const gridElement = document.getElementById('grid');
const board = ['', '', '', '', '', '', '', '', ''];
let currentPlayer = 'X';
const resultText = document.getElementById('result'); // Assuming you have a <p id="result"> in your HTML

function createBoard() {
  for (let i = 0; i < 9; i++) {
    const cell = document.createElement('div');
    cell.className = 'cell';
    cell.addEventListener('click', () => handleCellClick(i));
    gridElement.appendChild(cell);
  }
  resultText.textContent = '';
}

function handleCellClick(index) {
  if (!board[index]) {
    board[index] = currentPlayer;
    render();
    let result = checkWinningResult();
    if (result) {
      if (result === 'draw') {
        resultText.textContent = "It's a draw! (Click to Restart)";
      } else {
        resultText.textContent = `${result} wins! (Click to Restart)`;
      }
      // Make the grid clickable to reset
      gridElement.removeEventListener('click', handleCellClick);
      setTimeout(() => {
        gridElement.addEventListener('click', resetGame);
      }, 1000);
    } else {
      currentPlayer = currentPlayer === 'X' ? 'O' : 'X'; // Switch players
    }
  }
}

// Function to check the winner
function checkWinningResult() {
  const winPatterns = [
    [0, 1, 2],
    [3, 4, 5],
    [6, 7, 8], // Horizontals
    [0, 3, 6],
    [1, 4, 7],
    [2, 5, 8], // Verticals
    [0, 4, 8],
    [2, 4, 6], // Diagonals
  ];

  for (const pattern of winPatterns) {
    const [a, b, c] = pattern;
    if (board[a] && board[a] === board[b] && board[a] === board[c]) {
      return board[a]; // Return the winner ('X' or 'O')
    }
  }

  // Check for draw - if all spaces are filled and no winner
  if (board.every((space) => space !== '')) {
    return 'draw';
  }

  return null; // No winner yet
}

function render() {
  const cells = document.querySelectorAll('.cell');
  for (let i = 0; i < cells.length; i++) {
    cells[i].textContent = board[i];
  }
}

function resetGame() {
  board.fill('');
  currentPlayer = 'X';
  resultText.textContent = '';
  render();
  gridElement.removeEventListener('click', resetGame);
  gridElement.addEventListener('click', handleCellClick);
}

// Initialize the game
createBoard();
